import inspect
import typing
from .base_response import BaseResponse
import vkbottle_types.objects


class GetServerUrlResponse(BaseResponse):
    response: "GetServerUrlResponseModel" = None


class GetServerUrlResponseModel(BaseResponse):
    endpoint: typing.Optional[str] = None
    key: typing.Optional[str] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()
